[Scummvm-cvs-logs] SF.net SVN: scummvm: [27665] scummvm/trunk/engines/scumm/input.cpp

fingolfin at users.sourceforge.net fingolfin at users.sourceforge.net
Sat Jun 23 16:19:39 CEST 2007


Revision: 27665
          http://scummvm.svn.sourceforge.net/scummvm/?rev=27665&view=rev
Author:   fingolfin
Date:     2007-06-23 07:16:04 -0700 (Sat, 23 Jun 2007)

Log Message:
-----------
Changed the way VAR_VERSION_KEY is handled

Modified Paths:
--------------
    scummvm/trunk/engines/scumm/input.cpp

Modified: scummvm/trunk/engines/scumm/input.cpp
===================================================================
--- scummvm/trunk/engines/scumm/input.cpp	2007-06-23 14:10:44 UTC (rev 27664)
+++ scummvm/trunk/engines/scumm/input.cpp	2007-06-23 14:16:04 UTC (rev 27665)
@@ -391,10 +391,12 @@
 
 void ScummEngine_v7::processKeyboard(Common::KeyState lastKeyHit) {
 
-	// COMI version string is hard coded in the engine, hence we don't
-	// invoke versionDialog here (it would only show nonsense).
-	// Dig/FT version strings are partly hard coded, too.
-	if (_game.version == 7 && lastKeyHit.ascii == VAR(VAR_VERSION_KEY)) {
+	// VAR_VERSION_KEY (usually ctrl-v) is used in COMI, Dig and FT to trigger
+	// a version dialog, unless VAR_VERSION_KEY is set to 0. However, the COMI
+	// version string is hard coded in the engine, hence we don't invoke
+	// versionDialog for it. Dig/FT version strings are partly hard coded, too.
+	if (_game.id != GID_CMI && 0 != VAR(VAR_VERSION_KEY) &&
+	    lastKeyHit.keycode == Common::KEYCODE_v && lastKeyHit.flags == Common::KBD_CTRL) {
 		versionDialog();
 		return;
 	}


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list